aboutsummaryrefslogtreecommitdiffstats
path: root/apps/app_queue.c
diff options
context:
space:
mode:
authordvossel <dvossel@f38db490-d61c-443f-a65b-d21fe96a405b>2009-12-23 19:14:05 +0000
committerdvossel <dvossel@f38db490-d61c-443f-a65b-d21fe96a405b>2009-12-23 19:14:05 +0000
commit566562afc1334b934083e8d2315e2cae42372685 (patch)
tree3c47b962536175f1bb541d911c47fc45521cf649 /apps/app_queue.c
parent2125013a5fd189dcb3c6da560fdcc19140f6d529 (diff)
QUEUE_MEMBER(..., ready) counts only ready agents, not free agents wrapping up
The QUEUE_MEMBER dialplan function can return total members, logged-in members and "free" members count. A member is counted as "free" immediately after his call ends, even though its wrap-up time, if specified in queues.conf, has not yet expired, and the queue will not actually route a call to it. This Patch introduces a new "ready" option that only counts free agents no longer in the wrap up time period. (closes issue #16240) Reported by: kkm Patches: appqueue-memberfun-readyoption-trunk.diff uploaded by kkm (license 888) Tested by: kkm, dvossel git-svn-id: http://svn.digium.com/svn/asterisk/trunk@236308 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'apps/app_queue.c')
-rw-r--r--apps/app_queue.c22
1 files changed, 19 insertions, 3 deletions
diff --git a/apps/app_queue.c b/apps/app_queue.c
index a36713630..29fc040db 100644
--- a/apps/app_queue.c
+++ b/apps/app_queue.c
@@ -437,7 +437,10 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision$")
<para>Returns the number of logged-in members for the specified queue.</para>
</enum>
<enum name="free">
- <para>Returns the number of logged-in members for the specified queue available to take a call.</para>
+ <para>Returns the number of logged-in members for the specified queue that either can take calls or are currently wrapping up after a previous call.</para>
+ </enum>
+ <enum name="ready">
+ <para>Returns the number of logged-in members for the specified queue that are immediately available to answer a call.</para>
</enum>
<enum name="count">
<para>Returns the total number of members for the specified queue.</para>
@@ -5793,8 +5796,8 @@ static int queue_function_var(struct ast_channel *chan, const char *cmd, char *d
}
/*!
* \brief Get number either busy / free or total members of a specific queue
* \retval number of members (busy / free / total)
* \retval -1 on error
*/
static int queue_function_qac(struct ast_channel *chan, const char *cmd, char *data, char *buf, size_t len)
@@ -5836,6 +5839,19 @@ static int queue_function_qac(struct ast_channel *chan, const char *cmd, char *d
ao2_ref(m, -1);
}
ao2_iterator_destroy(&mem_iter);
+ } else if (!strcasecmp(option, "ready")) {
+ time_t now;
+ time(&now);
+ mem_iter = ao2_iterator_init(q->members, 0);
+ while ((m = ao2_iterator_next(&mem_iter))) {
+ /* Count the agents who are logged in, not paused and not wrapping up */
+ if ((m->status == AST_DEVICE_NOT_INUSE) && (!m->paused) &&
+ !(m->lastcall && q->wrapuptime && ((now - q->wrapuptime) < m->lastcall))) {
+ count++;
+ }
+ ao2_ref(m, -1);
+ }
+ ao2_iterator_destroy(&mem_iter);
} else /* must be "count" */
count = q->membercount;
ao2_unlock(q);
@@ -5793,8 +5796,8 @@ static int queue_function_var(struct ast_channel *chan, const char *cmd, char *d
}
/*!
- * \brief Get number either busy / free or total members of a specific queue
- * \retval number of members (busy / free / total)
+ * \brief Get number either busy / free / ready or total members of a specific queue
+ * \retval number of members (busy / free / ready / total)
* \retval -1 on error
*/